@@ -3,6 +3,6 @@
 const babelJest = require('babel-jest');
 const options = require('../optimize/babel/options');
 
-const babelOptions = options.webpack;
+const babelOptions = options.node;
 
 module.exports = babelJest.createTransformer(babelOptions);
